@@ -138,7 +138,7 @@ FILE * openAndVerify (char * filename, char extra1, char extra2, const char * er
 	FILE * fp = fopen (filename, "rb");
 	if (! fp) {
 		fatal ("Can't open file", filename);
-		return false;
+		return NULL;
 	}
 	bool headerBad = false;
 	if (fgetc (fp) != 'S') headerBad = true;
@@ -537,12 +537,12 @@ extern int cameraX, cameraY;
 extern float cameraZoom;
 
 bool checkColourChange (bool reset) {
-	static GLushort oldPixel;
-	static GLushort pixel;
+	static GLuint oldPixel;
+	static GLuint pixel;
 
 	glReadPixels((GLint)(viewportOffsetX+input.mouseX*viewportWidth/((float)winWidth/cameraZoom)),
         (GLint)(viewportOffsetY+(((float)winHeight/cameraZoom) - input.mouseY)*viewportHeight/((float)winHeight/cameraZoom)),
-        1, 1, GL_RGBA, GL_UNSIGNED_SHORT_4_4_4_4, &pixel);
+        1, 1, GL_RGBA, GL_UNSIGNED_BYTE, &pixel);
 
 	if (reset || oldPixel != pixel) {
 		oldPixel = pixel;
