@@ -80,15 +80,12 @@ bool initSoundStuff (HWND hwnd) {
 		modCache[a].playing = false;
 	}
 
-// Remove ifdef when switching to Alure 1.1 stable!
-#if defined __unix__ && !(defined __APPLE__)
-	if (! alureUpdateInterval(0.1))
+	if (! alureUpdateInterval(0.01))
 	{
 		debugOut("Failed to set Alure update interval: %s\n",
 				alureGetErrorString());
 		return 1;
 	}
-#endif
 	return soundOK = true;
 }
 
