@@ -4,6 +4,8 @@
 #include <libpng/png.h>
 #endif
 
+#include <string.h>
+
 #include "allfiles.h"
 
 #include "fileset.h"
@@ -59,6 +61,10 @@ void forgetSpriteBank (spriteBank & forgetme) {
 
 	delete forgetme.sprites;
 	forgetme.sprites = NULL;
+    
+    
+    // TODO: also remove sprite bank from allLoadedBanks
+    // And add a function call for this function to the scripting language
 }
 
 bool reserveSpritePal (spritePalette & sP, int n) {
